==> hyades.source_1.0.4.1.zip: org/eclipse/hyades/trace/ui/internal/actions/AttachActionDelegate.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.actions;

import org.eclipse.hyades.internal.execution.local.control.*;
import org.eclipse.hyades.loaders.util.LoadersUtils;
import org.eclipse.hyades.models.hierarchy.TRCAgentProxy;
import org.eclipse.hyades.models.hierarchy.TRCProcessProxy;
import org.eclipse.hyades.trace.internal.ui.PDProjectExplorer;
import org.eclipse.hyades.trace.ui.ProfileEvent;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.hyades.trace.ui.internal.piclient.PIProcessListener;
import org.eclipse.hyades.trace.ui.internal.util.PDCoreUtil;
import org.eclipse.jface.dialogs.MessageDialog;

/*
* CONTEXT_ID atha0000 for attach popup action
*/

public class AttachActionDelegate extends AbstractListenerActionDelegate {

	public void run(TRCAgentProxy fAgent, PDProjectExplorer fViewer) {

		TRCProcessProxy process = fAgent.getProcessProxy();
		String hostName = process.getNode().getName();

		try {			
			Node node = PDCoreUtil.profileConnect(hostName, String.valueOf(process.getNode().getPort()));
			if (node == null) {
					return;
			}

			Object instance = LoadersUtils.locateAgentInstance(fAgent);
			if(instance != null && instance instanceof Agent)
			{
				Agent a = (Agent)instance;
				if (a.isActive())
				{
					AgentListener listener = (AgentListener)LoadersUtils.locateAgentListener(fAgent); 
					if(listener != null && listener instanceof PIProcessListener)
					{
						((PIProcessListener)listener).monitor(true);
					}
					
					
					if (fAgent.isToProfileFile())
					{
						a.setProfileFile(fAgent.getProfileFile());					
					}
					else
					{
						a.setProfileFile(null);
					}	
					a.attach();
				}
			}

			ProfileEvent event = UIPlugin.getDefault().getProfileEvent();
			event.setSource(fAgent);
			event.setType(ProfileEvent.ATTACH);
			UIPlugin.getDefault().notifyProfileEventListener(event);

		}catch (Exception exc) {
			exc.printStackTrace();
		}

	}


	/**
	 * @see AbstractProfileActionDelegate#enableForMultiSelection()
	 */
	protected boolean enableForMultiSelection() {
		return false;
	}

	/**
	 * @see AbstractProfileActionDelegate#isEnabledFor(Object)
	 */
	protected boolean isEnabledFor(Object element) {

		if (element != null
			&& (element instanceof TRCAgentProxy)
			&& ((TRCAgentProxy) element).isActive()
			&& !((TRCAgentProxy) element).isAttached())
			return true;

		return false;

	}

	/**
	 * @see AbstractProfileActionDelegate#doAction(Object)
	 */
	public void doAction(Object object) throws Exception {

		if (object == null || !(object instanceof TRCAgentProxy))
			return;

		PDProjectExplorer fViewer = UIPlugin.getDefault().getViewer();
		if (fViewer == null) {
			MessageDialog.openInformation(
				UIPlugin.getActiveWorkbenchShell(),
				"title",
				"Action not available in current context");
			return;
		}

		run((TRCAgentProxy) object, fViewer);
	}
}

==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/trace/ui/internal/actions/AttachActionDelegate.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.actions;

import org.eclipse.hyades.internal.execution.local.control.Agent;
import org.eclipse.hyades.internal.execution.local.control.Node;
import org.eclipse.hyades.loaders.util.LoadersUtils;
import org.eclipse.hyades.models.hierarchy.TRCAgentProxy;
import org.eclipse.hyades.models.hierarchy.TRCProcessProxy;
import org.eclipse.hyades.trace.internal.ui.PDProjectExplorer;
import org.eclipse.hyades.trace.ui.ProfileEvent;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.hyades.trace.ui.internal.util.PDCoreUtil;
import org.eclipse.jface.dialogs.MessageDialog;

/*
* CONTEXT_ID atha0000 for attach popup action
*/

public class AttachActionDelegate extends AbstractListenerActionDelegate {

	public void run(TRCAgentProxy fAgent, PDProjectExplorer fViewer) {

		try {			
			TRCProcessProxy process = fAgent.getProcessProxy();
			String hostName = process.getNode().getName();
			Node node = PDCoreUtil.profileConnect(hostName, String.valueOf(process.getNode().getPort()));
			if (node == null) {
					return;
			}

			Object instance = LoadersUtils.locateAgentInstance(fAgent);
			if(instance != null && instance instanceof Agent)
			{
				Agent a = (Agent)instance;
				
				if (a.isActive())
				{
					if(fAgent.isActive())
					{
						PDCoreUtil.detachAgent(fAgent);
						fAgent.setActive(false);
					}
					
					TRCAgentProxy fAgentOld = fAgent;
					
					fAgent = PDCoreUtil.createUniqueAgent(process, a);
					
					PDCoreUtil.copyAgentProperties(fAgentOld,fAgent);
					
					PDCoreUtil.doAttach(a,fAgent);
					
					PDCoreUtil.activate(fAgent);

//					fAgent.setActive(true);
//					fAgent.setAttached(true);

//					AgentListener listener = (AgentListener)LoadersUtils.locateAgentListener(fAgent); 
//					if(listener != null && listener instanceof PIProcessListener)
//					{
//						((PIProcessListener)listener).monitor(true);
//					}
//					
//					
//					if (fAgent.isToProfileFile())
//					{
//						a.setProfileFile(fAgent.getProfileFile());					
//					}
//					else
//					{
//						a.setProfileFile(null);
//					}	
//					a.attach();
				}
			}

			ProfileEvent event = UIPlugin.getDefault().getProfileEvent();
			event.setSource(fAgent);
			event.setType(ProfileEvent.ATTACH);
			UIPlugin.getDefault().notifyProfileEventListener(event);

		}catch (Exception exc) {
			exc.printStackTrace();
		}

	}


	/**
	 * @see AbstractProfileActionDelegate#enableForMultiSelection()
	 */
	protected boolean enableForMultiSelection() {
		return false;
	}

	/**
	 * @see AbstractProfileActionDelegate#isEnabledFor(Object)
	 */
	protected boolean isEnabledFor(Object element) {

		if (element != null
			&& (element instanceof TRCAgentProxy)
			&& ((TRCAgentProxy) element).isActive()
			&& !((TRCAgentProxy) element).isAttached())
			return true;

		return false;

	}

	/**
	 * @see AbstractProfileActionDelegate#doAction(Object)
	 */
	public void doAction(Object object) throws Exception {

		if (object == null || !(object instanceof TRCAgentProxy))
			return;

		PDProjectExplorer fViewer = UIPlugin.getDefault().getViewer();
		if (fViewer == null) {
			MessageDialog.openInformation(
				UIPlugin.getActiveWorkbenchShell(),
				"title",
				"Action not available in current context");
			return;
		}

		run((TRCAgentProxy) object, fViewer);
	}
}
